==> nylon-cli-1.0.9.tgz: package/lib/server.js <==
/*!
    @Product nylon-cli
    @title nylon-cli
    @version 1.0
    @author somchit chanudom
    @email somchit.c@nexts-corp.com
    @homepage http://www.nexts-corp.com
    @licenses http://www.nexts-corp.com/product/license
    @Copyright (c) 2016-2017
*/
process.env.NODE_ENV=process.env.NODE_ENV || 'development';
const cluster = require('cluster');
const config=require(process.cwd()+'/config/config');
const watcher=require('./watcher');
const validator=require('./validator');
const rethinkdb=require('./rethinkdb');
const express =require('./express');
const http=require('http');
const passport =require('./passport');
const java = require('./java');
const iReport = require('./iReport');
const socket = require('./socket');
const http2 =require('spdy');
const fs =require('fs');



exports.serve= function(path){
    if (cluster.isMaster) {
        
        for (var i = 0; i < config.server.cluster; i++) {
            cluster.fork();
        }

        cluster.on('exit', (worker, code, signal) => {
            cluster.fork();
            console.log('worker '+worker.process.pid+' died');
        });

       watcher.addWatcher(process.cwd()+'/app');
       watcher.addWatcher(process.cwd()+'/config');

    }else{

        
        validator.loadSchema(process.cwd()+'/app/models');
        java.loadJava(path+"/java");

        var db  = rethinkdb(config);
        var app = express(db,config,validator.ajv,java.jvm);
        var server =http.createServer(app); 

        var options = {
            key: fs.readFileSync(__dirname + '/ssl/server.key'),
            cert: fs.readFileSync(__dirname + '/ssl/server.crt'),
            spdy: {
                    protocols: [ 'h2', 'spdy/3.1'],
                    plain: false,
                    'x-forwarded-for': true,
                    connection: {
                    windowSize: 1024 * 1024, 
                    autoSpdy31: false
                }
            }
        };

        var oauth=passport(db,config);
        
        server.listen(config.server.port, function (error) {
            console.error(error);
            console.log('Nylon server listening on port ' + config.server.port + ' pid '+process.pid);

            
        });


        process.on('uncaughtException', function(err){
            console.log(err);
            process.exit(1);
        });

        module.exports=app;
    }
}

==> nylon-cli-1.1.3.tgz: package/lib/server.js <==
/*!
    @Product nylon-cli
    @title nylon-cli
    @version 1.0
    @author somchit chanudom
    @email somchit.c@nexts-corp.com
    @homepage http://www.nexts-corp.com
    @licenses http://www.nexts-corp.com/product/license
    @Copyright (c) 2016-2017
*/
process.env.NODE_ENV=process.env.NODE_ENV || 'development';
const cluster = require('cluster');
const config=require(process.cwd()+'/config/config');

const watcher=require('./watcher');
const validator=require('./validator');
const rethinkdb=require('./rethinkdb');
const express =require('./express');
const http=require('http');
const passport =require('./passport');
const java = require('./java');
const iReport = require('./iReport');
const socket = require('./socket');
const http2 =require('spdy');
const fs =require('fs');



exports.serve= function(path){
    if (cluster.isMaster) {
        
        for (var i = 0; i < config.server.cluster; i++) {
            cluster.fork();
        }

        cluster.on('exit', (worker, code, signal) => {
            cluster.fork();
            console.log('worker '+worker.process.pid+' died');
        });

       watcher.addWatcher(process.cwd()+'/app');
       watcher.addWatcher(process.cwd()+'/config');

    }else{
        var fs_package = require('fs');
        var manifest = JSON.parse(fs.readFileSync(process.cwd()+'/public/manifest.json', 'utf8'));
        
        validator.loadSchema(process.cwd()+'/app/models');
        java.loadJava(path+"/java");

        var db  = rethinkdb(config);
        var app = express(db,config,validator.ajv,java.jvm,manifest);
        var server =http.createServer(app); 

        var options = {
            key: fs.readFileSync(__dirname + '/ssl/server.key'),
            cert: fs.readFileSync(__dirname + '/ssl/server.crt'),
            spdy: {
                    protocols: [ 'h2', 'spdy/3.1'],
                    plain: false,
                    'x-forwarded-for': true,
                    connection: {
                    windowSize: 1024 * 1024, 
                    autoSpdy31: false
                }
            }
        };

        var oauth=passport(db,config);
        
        server.listen(config.server.port, function (error) {
            console.error(error);
            console.log('Nylon server listening on port ' + config.server.port + ' pid '+process.pid);

            
        });


        process.on('uncaughtException', function(err){
            console.log(err);
            process.exit(1);
        });

        module.exports=app;
    }
}
